@@ -62,13 +62,9 @@ class GitProject:
         config.read(config_path)
         base_url = config.get('remote "origin"', "url")
         url = base_url.split("@", maxsplit=1)[-1] if '@' in base_url else base_url
-        url = url.replace(":", "/").replace(".git", '')
-        if "https" not in url:
-            if 'http' in url:
-                url = url.replace('http', 'https')
-            else:
-                url = f'https://' + url
-        parse = urlparse(url)
+        schema = 'http' if 'http://' in url else 'https://'
+        url = url.replace("https://", "").replace("http://", "").replace(":", "/").replace(".git", '')
+        parse = urlparse(f'{schema}' + url)
         return parse
 
     @staticmethod
